@@ -420,7 +420,10 @@ def populate_custom_snapshot(snapshot, container=None):
                                 if get_dbtests():
                                     if get_collection_size(data['collection']) == 0:
                                         #Creating indexes for collection
-                                        create_indexes(data['collection'], config_value(DATABASE, DBNAME), [('collection', pymongo.TEXT), ('snapshotId', pymongo.TEXT), ('structure', pymongo.TEXT)])
+                                        create_indexes(data['collection'],
+                                            config_value(DATABASE, DBNAME), 
+                                            [('snapshotId', pymongo.ASCENDING),
+                                            ('timestamp', pymongo.DESCENDING)])
                                     insert_one_document(data, data['collection'], dbname)
                                 else:
                                     snapshot_dir = make_snapshots_dir(container)
